from setuptools import setup, find_packages

setup(
    name="akilia",
    version="0.2.1",
    description="AI systems and low-field MRI tools for Africa",
    author="Leo Kinyera",
    author_email="leo@example.com",
    packages=find_packages(),
    install_requires=["matplotlib"],
    python_requires=">=3.8",
)
